==> jruby_1.7.22.orig.tar.gz: jruby-1.7.22/test/externals/ruby1.9/excludes/TestEncodingConverter.rb <==
exclude :test_accumulate_dst1, "needs investigation"
exclude :test_accumulate_dst2, "needs investigation"
exclude :test_after_output, "needs investigation"
exclude :test_asciicompat_encoding_iso2022jp, "needs investigation"
exclude :test_convert, "needs investigation"
exclude :test_convpath, "needs investigation"
exclude :test_errinfo_invalid_euc_jp, "needs investigation"
exclude :test_errinfo_invalid_euc_jp2, "needs investigation"
exclude :test_errinfo_invalid_partial_character, "needs investigation"
exclude :test_errinfo_invalid_utf16be, "needs investigation"
exclude :test_errinfo_invalid_utf16le, "needs investigation"
exclude :test_errinfo_undefined_hiragana, "needs investigation"
exclude :test_errinfo_valid_partial_character, "needs investigation"
exclude :test_errors, "needs investigation"
exclude :test_errors2, "needs investigation"
exclude :test_exc_incomplete, "needs investigation"
exclude :test_exc_invalid, "needs investigation"
exclude :test_exc_undef, "needs investigation"
exclude :test_finish_incomplete_error, "needs investigation"
exclude :test_invalid, "needs investigation"
exclude :test_invalid2, "needs investigation"
exclude :test_invalid3, "needs investigation"
exclude :test_invalid4, "needs investigation"
exclude :test_invalid_replace, "needs investigation"
exclude :test_invalid_utf16be, "needs investigation"
exclude :test_invalid_utf16le, "needs investigation"
exclude :test_invalid_utf32be, "needs investigation"
exclude :test_invalid_utf32le, "needs investigation"
exclude :test_iso2022jp_decode, "needs investigation"
exclude :test_iso2022jp_encode, "needs investigation"
exclude :test_iso2022jp_invalid_replace, "needs investigation"
exclude :test_last_error1, "needs investigation"
exclude :test_last_error2, "needs investigation"
exclude :test_newline_option, "unknown encoding name -"
exclude :test_noconv, "needs investigation"
exclude :test_noconv_after_output, "needs investigation"
exclude :test_noconv_insert_output, "needs investigation"
exclude :test_noconv_partial, "needs investigation"
exclude :test_output_iso2022jp, "needs investigation"
exclude :test_output_region, "needs investigation"
exclude :test_putback, "needs investigation"
exclude :test_putback2, "needs investigation"
exclude :test_s_new_convpath, "needs investigation"
exclude :test_s_new_fail, "needs investigation"
exclude :test_search_convpath, "needs investigation"
exclude :test_universal_newline3, "needs investigation"
exclude :test_xml_escape_attr_content, "needs investigation"
exclude :test_xml_escape_attr_quote, "needs investigation"
exclude :test_xml_escape_text, "needs investigation"
exclude :test_xml_escape_with_charref, "needs investigation"

==> jruby_1.7.26.orig.tar.gz: jruby-1.7.26/test/externals/ruby1.9/excludes/TestEncodingConverter.rb <==
windows = RbConfig::CONFIG['host_os'] =~ /mswin|mingw/

exclude :test_accumulate_dst1, "needs investigation"
exclude :test_accumulate_dst2, "needs investigation"
exclude :test_after_output, "needs investigation"
exclude :test_asciicompat_encoding_iso2022jp, "needs investigation"
exclude :test_convert, "needs investigation"
exclude :test_convpath, "needs investigation"
exclude :test_econv_new_hash, "needs investigation" if windows
exclude :test_errinfo_invalid_euc_jp, "needs investigation"
exclude :test_errinfo_invalid_euc_jp2, "needs investigation"
exclude :test_errinfo_invalid_partial_character, "needs investigation"
exclude :test_errinfo_invalid_utf16be, "needs investigation"
exclude :test_errinfo_invalid_utf16le, "needs investigation"
exclude :test_errinfo_undefined_hiragana, "needs investigation"
exclude :test_errinfo_valid_partial_character, "needs investigation"
exclude :test_errors, "needs investigation"
exclude :test_errors2, "needs investigation"
exclude :test_exc_incomplete, "needs investigation"
exclude :test_exc_invalid, "needs investigation"
exclude :test_exc_undef, "needs investigation"
exclude :test_finish_incomplete_error, "needs investigation"
exclude :test_get_replacement, "fails windows"
exclude :test_invalid, "needs investigation"
exclude :test_invalid2, "needs investigation"
exclude :test_invalid3, "needs investigation"
exclude :test_invalid4, "needs investigation"
exclude :test_invalid_replace, "needs investigation"
exclude :test_invalid_utf16be, "needs investigation"
exclude :test_invalid_utf16le, "needs investigation"
exclude :test_invalid_utf32be, "needs investigation"
exclude :test_invalid_utf32le, "needs investigation"
exclude :test_iso2022jp_decode, "needs investigation"
exclude :test_iso2022jp_encode, "needs investigation"
exclude :test_iso2022jp_invalid_replace, "needs investigation"
exclude :test_last_error1, "needs investigation"
exclude :test_last_error2, "needs investigation"
exclude :test_newline_option, "unknown encoding name -"
exclude :test_noconv, "needs investigation"
exclude :test_noconv_after_output, "needs investigation"
exclude :test_noconv_insert_output, "needs investigation"
exclude :test_noconv_partial, "needs investigation"
exclude :test_output_iso2022jp, "needs investigation"
exclude :test_output_region, "needs investigation"
exclude :test_putback, "needs investigation"
exclude :test_putback2, "needs investigation"
exclude :test_s_new_convpath, "needs investigation"
exclude :test_s_new_fail, "needs investigation"
exclude :test_search_convpath, "needs investigation"
exclude :test_universal_newline3, "needs investigation"
exclude :test_xml_escape_attr_content, "needs investigation"
exclude :test_xml_escape_attr_quote, "needs investigation"
exclude :test_xml_escape_text, "needs investigation"
exclude :test_xml_escape_with_charref, "needs investigation"
